@@ -1,41 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the QtSensors module of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:LGPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or (at your option) the GNU General
-** Public license version 3 or any later version approved by the KDE Free
-** Qt Foundation. The licenses are as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-2.0.html and
-** https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 #include "qsensormanager.h"
 #include <QDebug>
@@ -125,7 +89,7 @@ public:
                 //read out setting line
                 line.remove(QLatin1String(" "));
                 QStringList pair = line.split(QStringLiteral("="));
-                if (pair.count() == 2)
+                if (pair.size() == 2)
                     defaultIdentifierForType.insert(pair[0].toLatin1(), pair[1].toLatin1());
             }
         }
@@ -218,8 +182,8 @@ void QSensorManagerPrivate::loadPlugins()
         initPlugin(plugin, false /*do not warn on fail*/);
     if (d->loadExternalPlugins) {
         SENSORLOG() << "initializing plugins";
-        QList<QJsonObject> meta = d->loader->metaData();
-        for (int i = 0; i < meta.count(); i++) {
+        QList<QPluginParsedMetaData> meta = d->loader->metaData();
+        for (int i = 0; i < meta.size(); i++) {
             QObject *plugin = d->loader->instance(i);
             initPlugin(plugin);
         }
@@ -258,8 +222,8 @@ void QSensorManagerPrivate::loadPlugins()
 */
 void QSensorManager::registerBackend(const QByteArray &type, const QByteArray &identifier, QSensorBackendFactory *factory)
 {
-    Q_ASSERT(type.count());
-    Q_ASSERT(identifier.count());
+    Q_ASSERT(type.size());
+    Q_ASSERT(identifier.size());
     Q_ASSERT(factory);
     QSensorManagerPrivate *d = sensorManagerPrivate();
     if (!d) return; // hardly likely but just in case...
@@ -307,7 +271,7 @@ void QSensorManager::unregisterBackend(const QByteArray &type, const QByteArray
 
     (void)factoryByIdentifier.take(identifier); // we don't own this pointer anyway
     if (d->firstIdentifierForType[type] == identifier) {
-        if (factoryByIdentifier.count()) {
+        if (factoryByIdentifier.size()) {
             d->firstIdentifierForType[type] = factoryByIdentifier.begin().key();
             if (d->firstIdentifierForType[type].startsWith("generic.")) {
                 // Don't let a generic backend be the default when some other backend exists!
@@ -323,7 +287,7 @@ void QSensorManager::unregisterBackend(const QByteArray &type, const QByteArray
             (void)d->firstIdentifierForType.take(type);
         }
     }
-    if (!factoryByIdentifier.count())
+    if (!factoryByIdentifier.size())
         (void)d->backendsByType.take(type);
 
     // Notify the app that the available sensor list has changed.
